#!/usr/bin/perl -w

use Image::Magick;

if (scalar(@ARGV) != 1) {
	die("Usage: $0 <file>\n");
}
$filename = $ARGV[0];
die("File '$filename' not found\n") unless (-f $filename);

$image = Image::Magick->new;
$image->Read($filename);
$width = $image->Get('width');
$height = $image->Get('height');
print "Image size: $width x $height pixels.\n";
if ($width % 8 != 0) {
	$padwidth = int(($width + 7) / 8);
	print "Width is not divisible by 8, padding to $padwidth pixels.\n";
} else {
	$padwidth = $width;
}
@pixels = $image->GetPixels(map=>'I', width=>$width, height=>$height, normalize=>1);
open ASM, ">$filename.asm";

for ($y = 0; $y < $height; $y++) {
	print ASM ".db ";
	for ($x = 0; $x < $padwidth; $x += 8) {
		$byte = 0;
		for ($b = 7; $b >= 0; $b--) {
			if (($x < $width) and ($pixels[$y*$width + $x + 7-$b] < .5)) {
				$byte |= 1 << $b;
			}
		}
		if ($x > 0) {
			print ASM ", ";
		}
		printf ASM "0x%02x", $byte;
	}
	print ASM "\n";
}

close ASM;
